# Asgardeo App Extensions

|  Branch |Build Status | GitHub CI Status |
| :------------ |:------------- |:-------------
| master      | [![Build Status](https://wso2.org/jenkins/buildStatus/icon?job=iam-cloud%2Fasgardeo-app-extensions)](https://wso2.org/jenkins/job/iam-cloud/job/asgardeo-app-extensions/) | ![PR Builder](https://github.com/wso2-enterprise/asgardeo-app-extensions/workflows/PR%20Builder/badge.svg)|

Contains extensions which are applied on top of the parent [Identity Apps](https://github.com/wso2/identity-apps) respository to be used with [Asgardeo](https://github.com/wso2-enterprise/asgardeo-product).

## Setup build environment

1. Install NodeJS (v12.x) from [https://nodejs.org/en/download/](https://nodejs.org/en/download/).
2. Install Maven from [https://maven.apache.org/download.cgi](https://maven.apache.org/download.cgi).

## Build & Run

###  Build

1. Download or clone the project source code from [https://github.com/wso2-enterprise/asgardeo-app-extensions](https://github.com/wso2-enterprise/asgardeo-app-extensions).
2. Run `mvn clean install` from the command line in the project root directory (where the root `pom.xml` is located).

#### Build Archive

The final bundled archives will be located at `distrubutions/<APP>/target/identity-<APP>-v1.**-SNAPSHOT.war`.

### Run

#### Run against the Cloud Environment.

To run the apps i.e **Console** & **My Account** pointing to the Cloud environment, follow the steps below.

> :bulb: Following steps are for running **Console** against the cloud. Same approach is applicable for **My Account**.

- Navigate to the folder where the source-code of the desired app is located. For **Console**, go to `target/identity-apps/apps/console`.
- Open up the `index.html` file located at the root of `src` folder. And change the **contextPathGlobal** from `/console` to `""`.

```html
    <script>
        var contextPathGlobal = "";
        ...
    </script>
```
- Update deployment configurations.

Go to `src/public` & open up `deployment.config.json` in an editor and change the following configuration.

1. Change the app base name from `"console"` to `""`.

```json
{
    "appBaseName": "",
}
```

2. Change the `Server Origin`.

URL added will depend on the environment you wish to point. In this case dev cloud. (https://dev.accounts.asgardeo.io)

```json
{
    "idpConfigs": {
        "serverOrigin": "https://dev.accounts.asgardeo.io",
    },
    "serverOrigin": "https://dev.accounts.asgardeo.io",
}
```

3. Update IDP resource endpoints.

Update the `authorizeEndpointURL` & `logoutEndpointURL` accordingly.


> :bulb: Skipping this step will result in unexpected session persistence issue.

**Console**

```json
{
    "idpConfigs": {
        "authorizeEndpointURL": "${serverOrigin}/${tenantPrefix}/${superTenantDomain}/oauth2/authorize?ut=${userTenantDomain}",
        "logoutEndpointURL": "${serverOrigin}/${tenantPrefix}/${superTenantDomain}/oidc/logout",
    }
}
```

**My Account**

```json
{
    "idpConfigs": {
        "authorizeEndpointURL": "${serverOrigin}/${tenantPrefix}/${userTenantDomain}/common/oauth2/authorize",
        "logoutEndpointURL": "${serverOrigin}/${tenantPrefix}/${userTenantDomain}/common/oidc/logout",
    }
}
```

4. Add super tenant proxy.

> :bulb: With the tenant wise cookie handling, super tenant login flows have tenant path as /t/carbon.super. `superTenantProxy` is used to mask `carbon.super`.

```json
{
    "superTenantProxy" : "a",
}
```

> :bulb: Read more about these configs [here](https://github.com/wso2/identity-apps/blob/master/docs/CONFIGURATION.md).

- Add a the following mapping in your host file.

```dotenv
# Maps localhost to develeopment cloud's console host.
127.0.0.1 dev.console.asgardeo.io
```

> :bulb: In macOS, usually host file is located at `/private/etc/hosts`.

- Start the **Console** in port `443`.

```bash
npm start -- env DEV_SERVER_PORT=443 env DISABLE_DEV_SERVER_HOST_CHECK=true
```

- Once the dev server is up and running, navigate to [https://dev.console.asgardeo.io](https://dev.console.asgardeo.io) from your browser.

- Bypass the Certificate warning.

If you get an invalid certificate warning and don't see a button to bypass, try typing `thisisunsafe` at the window (Only works in Chrome).

## Development

### Adding a new extension
- Step 1
Add a new self explanatory named folder to the following path.
`app-extensions/console/src/extensions/components`

- Step 2
Add a new entry to the `config.js` located inside the `extensions` folder.


    module.exports = () => {
        return {
            sections: {
                components: {
                    "feedback-button": "./components/feedback/feedback.tsx"
    				// New entry of the extension with the path to the extension
                }
            }
        };

- Step 3 
Add necessary extension logic inside the above created extension folder.

## Deployment

Please configure the following configuration overrides in the `deployment.toml` file.

1. Configurations for the console.
```toml
[console]
product_version.configs.versionOverride = "BETA"                                 # Product version appearing in the app header.
theme = "asgardio"                                                               # Customized sub theme name.
ui.app_copyright = "Asgardeo by WSO2"                                            # Copyright for the footer.
ui.app_title = "Asgardeo Console"                                                # App title (Visble on the browser tab)
ui.app_name = "Console"                                                          # Name of the app appearing on the logo.
ui.product_name = "Asgardeo"                                                     # Name of the product.
route_paths.home = "/develop/getting-started"                                    # Default home path for the app. (User's will be redirected here upon successful login)
applications.developer_app.configs.path = "/develop/getting-started"             # Default page for the develop view.
applications.admin_app.configs.path = "/manage/getting-started"                  # Default page for the manage view.
general_configurations.enabled = false                                           # Hides governance connectors.
session.params.userIdleTimeOut = 90000                                           # When to timeout IDLE user sessions.
session.params.userIdleWarningTimeOut = 89980                                    # When to warn users of IDLE user session timeouts.
session.params.sessionRefreshTimeOut = 1800                                      # Session reset timeout.
session.params.checkSessionInterval = 5                                          # How frequent the check session should occur.
```

2. Configurations for the My Account.

```toml
[myaccount]
product_version.configs.versionOverride = "BETA"                                 # Product version appearing in the app header.
theme = "asgardio"                                                               # Customized sub theme name.
ui.app_copyright = "Asgardeo by WSO2"                                            # Copyright for the footer.
ui.app_title = "Asgardeo Account"                                                # App title (Visble on the browser tab)
ui.app_name = "Account"                                                          # Name of the app appearing on the logo.
ui.product_name = "Asgardeo"                                                     # Name of the product.
session.params.userIdleTimeOut = 90000                                           # When to timeout IDLE user sessions.
session.params.userIdleWarningTimeOut = 89980                                    # When to warn users of IDLE user session timeouts.
session.params.sessionRefreshTimeOut = 1800                                      # Session reset timeout.
session.params.checkSessionInterval = 5                                          # How frequent the check session should occur.
```
